@@ -409,31 +409,6 @@ class TestBakeWait:
         assert bitbake.wait() is last
 
 
-@pytest.fixture
-def build_attrs():
-    return {
-        "group": "tuxsuite",
-        "project": "unittests",
-        "git_repo": "http://github.com/torvalds/linux",
-        "git_ref": "master",
-        "target_arch": "arm",
-        "kconfig": "defconfig",
-        "build_name": "test_build_name",
-        "toolchain": "gcc-9",
-        "token": "test_token",
-        "kbapi_url": "http://test/foo",
-        "tuxapi_url": "http://tuxapi",
-        "kernel_image": "Image",
-    }
-
-
-@pytest.fixture
-def build(build_attrs):
-    b = tuxsuite.build.Build(**build_attrs)
-    b.uid = "myuid"
-    return b
-
-
 class TestBuild:
     def test_kconfig(self, build):
         assert type(build.kconfig) == list
