@@ -90,7 +90,21 @@ def test_plan_config(plan_config):
     }
     assert cfg.plan[8]["tests"] == [
         {"device": "qemu-i386"},
-        {"device": "qemu-i386", "tests": ["ltp-smoke"]},
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 1},
+        },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 2},
+        },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 3},
+        },
     ]
 
     assert cfg.plan[9]["build"] == {
@@ -100,7 +114,21 @@ def test_plan_config(plan_config):
     }
     assert cfg.plan[9]["tests"] == [
         {"device": "qemu-i386"},
-        {"device": "qemu-i386", "tests": ["ltp-smoke"]},
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 1},
+        },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 2},
+        },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 3},
+        },
     ]
 
     assert cfg.plan[10]["build"] == {
@@ -110,7 +138,21 @@ def test_plan_config(plan_config):
     }
     assert cfg.plan[10]["tests"] == [
         {"device": "qemu-i386"},
-        {"device": "qemu-i386", "tests": ["ltp-smoke"]},
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 1},
+        },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 2},
+        },
+        {
+            "device": "qemu-i386",
+            "tests": ["ltp-syscalls"],
+            "parameters": {"SHARD_NUMBER": 3, "SHARD_INDEX": 3},
+        },
     ]
 
     assert cfg.plan[11]["build"] is None
@@ -246,7 +288,7 @@ def test_submit(config, plan_config, mocker):
             return builds
         if url == "https://tuxapi.tuxsuite.com/v1/groups/tuxgrp/projects/tuxprj/tests":
             assert isinstance(data, list)
-            assert len(data) == 21
+            assert len(data) == 27
 
             tests = []
             for p in cfg.plan:
@@ -269,11 +311,17 @@ def test_submit(config, plan_config, mocker):
             assert data[8]["waiting_for"] == "my-build-07"
             assert data[9]["waiting_for"] == "my-build-08"
             assert data[10]["waiting_for"] == "my-build-08"
-            assert data[11]["waiting_for"] == "my-build-09"
-            assert data[12]["waiting_for"] == "my-build-09"
-            assert data[13]["waiting_for"] == "my-build-10"
-            assert data[14]["waiting_for"] == "my-build-10"
-            for i in range(15, 21):
+            assert data[11]["waiting_for"] == "my-build-08"
+            assert data[12]["waiting_for"] == "my-build-08"
+            assert data[13]["waiting_for"] == "my-build-09"
+            assert data[14]["waiting_for"] == "my-build-09"
+            assert data[15]["waiting_for"] == "my-build-09"
+            assert data[16]["waiting_for"] == "my-build-09"
+            assert data[17]["waiting_for"] == "my-build-10"
+            assert data[18]["waiting_for"] == "my-build-10"
+            assert data[19]["waiting_for"] == "my-build-10"
+            assert data[20]["waiting_for"] == "my-build-10"
+            for i in range(21, 27):
                 assert "waiting_for" not in data[i]
                 assert "kernel" in data[i]
 
@@ -287,7 +335,7 @@ def test_submit(config, plan_config, mocker):
     plan.submit()
 
     assert len(plan.builds) == 11
-    assert len(plan.tests) == 21
+    assert len(plan.tests) == 27
 
 
 def test_bake_submit(config, bake_plan_config, mocker):
