@@ -266,6 +266,8 @@ def handle_submit(cmdargs, _, config):
             git_sha=cmdargs.git_sha,
             git_ref=cmdargs.git_ref,
             patch_series=cmdargs.patch_series,
+            no_cache=cmdargs.no_cache,
+            local_manifest=cmdargs.local_manifest,
         )
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
         error(e)
