@@ -76,8 +76,8 @@ def handle_fetch(cmdargs, _, config):
     test = cmdargs.test
     plan = cmdargs.plan
     oebuild = cmdargs.oebuild
-
     result_json = {}
+
     try:
         results = tuxsuite.Results()
     except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
@@ -95,14 +95,31 @@ def handle_fetch(cmdargs, _, config):
             elif "sources" in data:
                 oebuild = data["uid"]
             elif isinstance(data, list):
-                # TODO: ---> for bake required or not ?
-                result_json = []
+                # Now can able to parse and fetch results of build/tests/oebuilds from json file
+                # TODO - list of plans not included yet
+                result_json_map = {}
+                result_list = []
+                result_json, tuxapi_url = results.get_all()
+                result_json.pop("plans", None)
+                # prepare map of results based on their ksuids
+                for key in result_json.keys():
+                    for result in result_json[key].get("results", None):
+                        result_json_map[result["uid"]] = {
+                            **result,
+                            **{"tuxapi_url": f"{tuxapi_url}/{key}/{result['uid']}"},
+                        }
+
                 for res in data:
-                    results.uid = res["uid"]
-                    build_result = results.get_build()
-                    format_result(build_result)
-                    if cmdargs.json_out:
-                        result_json.append(build_result)
+                    if result_json_map.get(res["uid"], None):
+                        result, tuxapi_url = (
+                            result_json_map[res["uid"]],
+                            result_json_map[res["uid"]]["tuxapi_url"],
+                        )
+                        format_result(result, tuxapi_url)
+                        if cmdargs.json_out:
+                            result_list.append(result)
+                result_json = result_list
+
         elif not any([build, test, plan, oebuild]):  # get all results with no options
             result_json, tuxapi_url = results.get_all()
             for key in result_json.keys():
@@ -111,15 +128,9 @@ def handle_fetch(cmdargs, _, config):
                     if key == "plans":
                         print(f"{result['uid']}: {result['name']} {result['project']}")
                     else:
-                        # tuxapi-url is basically base tuxapi url ( we don't know if it is of build/oebuilds/test)
-                        key_type_map = {
-                            "oebuilds": f"{tuxapi_url}/oebuilds",
-                            "builds": f"{tuxapi_url}/builds",
-                            "tests": f"{tuxapi_url}/tests",
-                        }
-
-                        format_result(result, f"{key_type_map[key]}/{result['uid']}")
+                        format_result(result, f"{tuxapi_url}/{key}/{result['uid']}")
                 print("\n")
+
         if build:
             results.uid = build
             result_json, tuxapi_build_url = results.get_build()
