@@ -1,10 +1,20 @@
 # -*- coding: utf-8 -*-
 
+import argparse
+import tuxsuite
 import tuxsuite.cli.colors as colors
 import tuxsuite.cli.icons as icons
 from tuxsuite.cli.models import Test
-from tuxsuite.cli.requests import apiurl, get, post
-from tuxsuite.cli.utils import LIMIT, datediff, fetch_next
+from tuxsuite.cli.requests import apiurl, get
+from tuxsuite.cli.utils import (
+    LIMIT,
+    datediff,
+    fetch_next,
+    key_value,
+    wait_for_object,
+    format_result,
+    error,
+)
 from tuxsuite.cli.yaml import yaml_load
 
 import json
@@ -27,7 +37,7 @@ COLORS = {
 }
 
 
-def handle_get(options, config):
+def handle_get(options, _, config):
     ret = get(
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/tests/{options.uid}",
@@ -78,7 +88,7 @@ def handle_get(options, config):
     return 0
 
 
-def handle_list(options, config):
+def handle_list(options, _, config):
     url = f"/v1/groups/{config.group}/projects/{config.project}/tests"
     ret = get(config, url)
     if ret.status_code != 200:
@@ -112,7 +122,7 @@ def handle_list(options, config):
     return 0
 
 
-def handle_logs(options, config):
+def handle_logs(options, _, config):
     ret = get(
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/tests/{options.uid}/logs/lava",
@@ -136,7 +146,7 @@ def handle_logs(options, config):
     return 0
 
 
-def handle_results(options, config):
+def handle_results(options, _, config):
     ret = get(
         config,
         f"/v1/groups/{config.group}/projects/{config.project}/tests/{options.uid}/results",
@@ -160,38 +170,7 @@ def handle_results(options, config):
     return 0
 
 
-def handle_submit(options, config):
-    data = {"device": options.device}
-    if options.kernel is not None:
-        data["kernel"] = options.kernel
-    if options.modules is not None:
-        data["modules"] = options.modules
-    if options.tests:
-        data["tests"] = options.tests
-    if options.plan:
-        data["plan"] = options.plan
-    if options.build:
-        data["wait_for"] = options.build
-
-    ret = post(
-        config, f"/v1/groups/{config.group}/projects/{config.project}/tests", data=data
-    )
-    if ret.status_code != 201:
-        raise NotImplementedError
-    data = ret.json()
-    test = Test.new(**data)
-    if options.wait:
-        options.uid = test.uid
-        return handle_wait(options, config)
-
-    if options.json:
-        print(test.as_json())
-    else:
-        print(test)
-    return 0
-
-
-def handle_wait(options, config):
+def handle_wait(options, _, config):
     previous_state = None
     while True:
         ret = get(
@@ -251,6 +230,80 @@ def handle_wait(options, config):
     return 0
 
 
+def handle_submit(cmdargs, _, config):
+    if not cmdargs.device:
+        error("--device is a required argument")
+
+    tests = [test for test in cmdargs.tests.split(",") if test]
+    tests = [test for test in tests if test != "boot"]
+    if cmdargs.wait_for:
+        print(
+            "Testing build {} on {} with {}".format(
+                cmdargs.wait_for, cmdargs.device, ", ".join(["boot"] + tests)
+            )
+        )
+        if cmdargs.kernel:
+            error("--kernel and --wait-for are mutually exclusive")
+        if cmdargs.modules:
+            error("--modules and --wait-for are mutually exclusive")
+    else:
+        print(
+            "Testing {} on {} with {}".format(
+                cmdargs.kernel, cmdargs.device, ", ".join(["boot"] + tests)
+            )
+        )
+
+    params = {}
+    for p in cmdargs.parameters:
+        params[p[0][0]] = p[0][1]
+
+    timeouts_d = {}
+    for t in cmdargs.timeouts:
+        timeouts_d[t[0][0]] = int(t[0][1])
+
+    try:
+        test = tuxsuite.Test(
+            device=cmdargs.device,
+            kernel=cmdargs.kernel,
+            ap_romfw=cmdargs.ap_romfw,
+            dtb=cmdargs.dtb,
+            mcp_fw=cmdargs.mcp_fw,
+            mcp_romfw=cmdargs.mcp_romfw,
+            modules=cmdargs.modules,
+            rootfs=cmdargs.rootfs,
+            scp_fw=cmdargs.scp_fw,
+            scp_romfw=cmdargs.scp_romfw,
+            fip=cmdargs.fip,
+            parameters=params,
+            tests=tests,
+            timeouts=timeouts_d,
+            boot_args=cmdargs.boot_args,
+            wait_for=cmdargs.wait_for,
+        )
+    except (AssertionError, tuxsuite.exceptions.TuxSuiteError) as e:
+        error(e)
+
+    try:
+        test.test()
+        print("uid: {}".format(test.uid))
+    except tuxsuite.exceptions.BadRequest as e:
+        error(str(e))
+
+    test_result = True
+
+    if cmdargs.no_wait:
+        format_result(test.status, test.url)
+    else:
+        test_result = wait_for_object(test)
+
+    if cmdargs.json_out:
+        cmdargs.json_out.write(json.dumps(test.status, sort_keys=True, indent=4))
+
+    # If the test did not pass, exit with exit code of 1
+    if not test_result:
+        sys.exit(1)
+
+
 handlers = {
     "get": handle_get,
     "list": handle_list,
@@ -261,6 +314,109 @@ handlers = {
 }
 
 
+def test_cmd_options(sp):
+    sp.add_argument(
+        "--device",
+        help="Device type",
+        type=str,
+    )
+    sp.add_argument(
+        "--kernel",
+        help="URL of the kernel to test",
+        default=None,
+        type=str,
+    )
+    sp.add_argument(
+        "--dtb",
+        help="URL of the dtb to test",
+        default=None,
+        type=str,
+    )
+    sp.add_argument(
+        "--mcp-fw", help="URL of the MCP firmware to test", default=None, type=str
+    )
+    sp.add_argument(
+        "--mcp-romfw",
+        help="URL of the MCP ROM firmware to test",
+        default=None,
+        type=str,
+    )
+    sp.add_argument(
+        "--modules",
+        help="URL of the kernel modules",
+        default=None,
+        type=str,
+    )
+    sp.add_argument(
+        "--rootfs",
+        help="URL of the rootfs to test",
+        default=None,
+        type=str,
+    )
+    sp.add_argument(
+        "--scp-fw", help="URL of the SCP firmware to test", default=None, type=str
+    )
+    sp.add_argument(
+        "--ap-romfw",
+        help="URL of the AP ROM firmware to test",
+        default=None,
+        type=str,
+    )
+    sp.add_argument(
+        "--scp-romfw",
+        help="URL of the SCP ROM firmware to test",
+        default=None,
+        type=str,
+    )
+    sp.add_argument("--fip", help="URL of the fip.bin to test", default=None, type=str)
+    sp.add_argument(
+        "--parameters",
+        help="test parameters as KEY=VALUE",
+        default=[],
+        type=key_value,
+        nargs="*",
+        action="append",
+    )
+    sp.add_argument(
+        "--tests",
+        help="Comma separated list of tests",
+        default="boot",
+        type=str,
+    )
+    sp.add_argument(
+        "--timeouts",
+        help="timeouts as KEY=VALUE",
+        default=[],
+        type=key_value,
+        nargs="*",
+        action="append",
+    )
+    sp.add_argument(
+        "--boot-args",
+        help="Extra boot arguments",
+        default=None,
+        type=str,
+    )
+    sp.add_argument(
+        "--wait-for",
+        help="Wait for a test uid",
+        default=None,
+        type=str,
+    )
+    sp.add_argument(
+        "-n",
+        "--no-wait",
+        default=False,
+        action="store_true",
+        help="Don't wait for tests to finish",
+    )
+    sp.add_argument(
+        "--json-out",
+        help="Write json test status out to a named file path",
+        type=argparse.FileType("w", encoding="utf-8"),
+    )
+
+
 def setup_parser(parser):
     # "test get <uid>"
     t = parser.add_parser("get")
@@ -284,15 +440,10 @@ def setup_parser(parser):
 
     # "test submit"
     t = parser.add_parser("submit")
-    t.add_argument("--device", required=True)
-    t.add_argument("--kernel", default=None)
-    t.add_argument("--modules", default=None)
-    t.add_argument("--tests", default=[], nargs="+")
-    t.add_argument("--plan", default=None)
-    t.add_argument("--build", default=None)
-    t.add_argument("--json", action="store_true")
-    t.add_argument("--wait", action="store_true")
+    test_cmd_options(t)
 
     # "test wait <uid>
     t = parser.add_parser("wait")
     t.add_argument("uid")
+
+    return sorted(parser._name_parser_map.keys())
