@@ -9,7 +9,7 @@ def download(build, output):
     output.mkdir(exist_ok=True)
     build_dir = output / build.uid
     build_dir.mkdir(exist_ok=True)
-    files = get(build.build_data + "?export=json").json()
+    files = get(build.status["download_url"] + "?export=json").json()
     # TODO parallelize?
     for f in files["files"]:
         url = f["Url"]
